@@ -10,8 +10,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import re
-
 import testtools
 
 from neutron_lib.hacking import checks
@@ -28,10 +26,41 @@ class HackingTestCase(base.BaseTestCase):
     def assertLineFails(self, func, *args):
         self.assertIsInstance(next(func(*args)), tuple)
 
+    def _get_factory_checks(self, factory):
+        check_fns = []
+
+        def _reg(check_fn):
+            self.assertTrue(hasattr(check_fn, '__call__'))
+            self.assertFalse(check_fn in check_fns)
+            check_fns.append(check_fn)
+
+        factory(_reg)
+        return check_fns
+
     def test_factory(self):
-        def check_callable(fn):
-            self.assertTrue(hasattr(fn, '__call__'))
-        self.assertIsNone(checks.factory(check_callable))
+        self.assertTrue(len(self._get_factory_checks(checks.factory)) > 0)
+
+    def test_incubating_factory(self):
+        incubating_checks = self._get_factory_checks(
+            checks.incubating_factory)
+
+        if incubating_checks:
+            adopter_checks = self._get_factory_checks(checks.factory)
+            for incubating_check in incubating_checks:
+                self.assertFalse(incubating_check in adopter_checks)
+
+    def test_neutron_lib_factory(self):
+        lib_checks = self._get_factory_checks(checks._neutron_lib_factory)
+        other_checks = self._get_factory_checks(checks.factory)
+        other_checks.extend(self._get_factory_checks(
+            checks.incubating_factory))
+
+        self.assertTrue(len(lib_checks) > 0)
+
+        if other_checks:
+            for other_check in other_checks:
+                # lib checks are superset of all checks
+                self.assertTrue(other_check in lib_checks)
 
     def test_use_jsonutils(self):
         def __get_msg(fun):
@@ -182,38 +211,6 @@ class HackingTestCase(base.BaseTestCase):
         self.assertLinePasses(f, "raise KeyError('Error text')",
                               'neutron_lib/tests/unit/mytest.py')
 
-    def test_check_delayed_string_interpolation(self):
-        dummy_noqa = re.search('a', 'a')
-        f = tc.check_delayed_string_interpolation
-
-        # In 'logical_line', Contents of strings replaced with
-        # "xxx" of same length.
-        self.assertLineFails(f, 'LOG.error(_LE("xxxxxxxxxxxxxxx") % value)',
-                             'neutron_lib/db/utils.py', None)
-        self.assertLineFails(f, "LOG.warning(msg % 'xxxxx')",
-                             'neutron_lib/db/utils.py', None)
-        self.assertLineFails(f, "LOG.info(_LI('xxxxxxxxxxxxxxxxxxxxxxxxx"
-                                "xxxxxxxxx') % {'xx': v1, 'xx': v2})",
-                             'neutron_lib/db/utils.py', None)
-
-        self.assertLinePasses(
-            f, 'LOG.error(_LE("xxxxxxxxxxxxxxxxxx"), value)',
-            'neutron_lib/db/utils.py', None)
-        self.assertLinePasses(f, "LOG.warning(msg, 'xxxxx')",
-                              'neutron_lib/db/utils.py', None)
-        self.assertLinePasses(f, "LOG.info(_LI('xxxxxxxxxxxxxxxxxxxxxxxx"
-                                 "xxxxxxxxx'), {'xx': v1, 'xx': v2})",
-                              'neutron_lib/db/utils.py', None)
-
-        # check a file in neutron_lib/tests
-        self.assertLinePasses(f, 'LOG.error(_LE("xxxxxxxxxxxxxxx") % value)',
-                              'neutron_lib/tests/unit/test_neutron_lib.py',
-                              None)
-        # check code including 'noqa'
-        self.assertLinePasses(f, 'LOG.error(_LE("xxxxxxxxxxxxxxx") % value)',
-                              'neutron_lib/db/utils.py',
-                              dummy_noqa)
-
     def test_check_eventlet_imports(self):
         f = checks.check_no_eventlet_imports
         self.assertLineFails(f, "import eventlet")
@@ -228,3 +225,25 @@ class HackingTestCase(base.BaseTestCase):
         self.assertLinePasses(f, 'print("eventlet not here")')
         self.assertLinePasses(f, 'print("eventlet.timeout")')
         self.assertLinePasses(f, "from mymod.timeout import (eventlet, X)")
+
+    def test_assert_equal_none(self):
+        self.assertEqual(len(list(checks.assert_equal_none(
+            "self.assertEqual(A, None)"))), 1)
+        self.assertEqual(len(list(checks.assert_equal_none(
+            "self.assertEqual(A, None)  # Comment"))), 1)
+        self.assertEqual(len(list(checks.assert_equal_none(
+            "self.assertEqual(None, A)"))), 1)
+        self.assertEqual(len(list(checks.assert_equal_none(
+            "self.assertEqual(None, A)  # Comment"))), 1)
+        self.assertEqual(len(list(checks.assert_equal_none(
+            "assertIsNot(A, None)"))), 1)
+        self.assertEqual(len(list(checks.assert_equal_none(
+            "assertIsNot(A, None)  # Comment"))), 1)
+        self.assertEqual(len(list(checks.assert_equal_none(
+            "assertIsNot(None, A)"))), 1)
+        self.assertEqual(len(list(checks.assert_equal_none(
+            "assertIsNot(None, A)  # Comment"))), 1)
+        self.assertEqual(
+            len(list(checks.assert_equal_none("self.assertIsNone(A)"))), 0)
+        self.assertEqual(
+            len(list(checks.assert_equal_none("self.assertIsNotNone(A)"))), 0)
